@@ -15,13 +15,13 @@ use constant {
   GETGROUPLIST_COUNT_MAX => 65536,
 };
 
-our $VERSION = '0.002';
+our $VERSION = '1.000';
 
 our @EXPORT_OK = qw(getgroups setgroups getgrouplist initgroups);
 
 our @CARP_NOT = qw(FFI::Platypus);
 
-my $ffi = FFI::Platypus->new(lib => [undef], ignore_not_found => 1);
+my $ffi = FFI::Platypus->new(api => 1, lib => [undef], ignore_not_found => 1);
 
 $ffi->attach(getgroups => ['int', 'gid_t[]'] => 'int', sub {
   my ($xsub) = @_;
